package com.mortals.xhx.module.check.web;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.OrderCol;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.common.code.CheckStatusEnum;
import com.mortals.xhx.common.code.CheckTypeEnum;
import com.mortals.xhx.common.code.SubAddTypeEnum;
import com.mortals.xhx.common.code.SubMethodEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.check.model.CheckAttendRecordEntity;
import com.mortals.xhx.module.check.service.CheckAttendRecordService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;

import java.util.Arrays;

import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import static com.mortals.framework.ap.SysConstains.*;

/**
 * 考勤绩效记录核查信息
 *
 * @author zxfei
 * @date 2023-07-10
 */
@RestController
@RequestMapping("check/attend/record")
public class CheckAttendRecordController extends BaseCRUDJsonBodyMappingController<CheckAttendRecordService, CheckAttendRecordEntity, Long> {

    @Autowired
    private ParamService paramService;

    public CheckAttendRecordController() {
        super.setModuleDesc("考勤绩效记录核查信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
       this.addDict(model, "checkStatus", CheckStatusEnum.getEnumMap());
        this.addDict(model, "subMethod", SubMethodEnum.getEnumMap());
        this.addDict(model, "subAddType", SubAddTypeEnum.getEnumMap());
        this.addDict(model, "checkType", CheckTypeEnum.getEnumMap());

        super.init(model, context);
    }


    @Override
    protected void doListBefore(CheckAttendRecordEntity query, Map<String, Object> model, Context context) throws AppException {

        if (ObjectUtils.isEmpty(query.getOrderColList())) {
            query.setOrderColList(Arrays.asList(new OrderCol("createTime", OrderCol.DESCENDING)));
        } else {
            query.getOrderColList().add(new OrderCol("createTime", OrderCol.DESCENDING));
        }
        super.doListBefore(query, model, context);
    }

    /**
     * 审核
     *
     * @param entity
     * @return
     */
    @PostMapping({"examine"})
    public String examine(@RequestBody CheckAttendRecordEntity entity) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        int code = 1;
        String busiDesc = "考勤绩效核查审核";
        try {
            this.service.examine(entity, context);
            model.put("id", entity.getId());
            model.put("entity", entity);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + entity.getId() + "]");
        } catch (Exception var9) {
            this.doException(this.request, busiDesc, model, var9);
            model.put("entity", entity);
            this.init(model, context);
            code = this.saveException(entity, model, context, var9);
        }

        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

}