package com.mortals.xhx.module.perform.service.impl;
import com.mortals.xhx.common.code.CheckStatusEnum;
import com.mortals.xhx.common.code.SubMethodEnum;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.module.check.model.CheckEffectRecordEntity;
import com.mortals.xhx.module.check.service.CheckEffectRecordService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.perform.dao.PerformEffectRecordDao;
import com.mortals.xhx.module.perform.model.PerformEffectRecordEntity;
import com.mortals.xhx.module.perform.service.PerformEffectRecordService;
import lombok.extern.slf4j.Slf4j;

import java.util.Date;

/**
* PerformEffectRecordService
* 效能绩效记录信息 service实现
*
* @author zxfei
* @date 2023-07-11
*/
@Service("performEffectRecordService")
@Slf4j
public class PerformEffectRecordServiceImpl extends AbstractCRUDServiceImpl<PerformEffectRecordDao, PerformEffectRecordEntity, Long> implements PerformEffectRecordService {

    @Autowired
    private CheckEffectRecordService checkEffectRecordService;

    @Override
    protected void saveAfter(PerformEffectRecordEntity entity, Context context) throws AppException {
        CheckEffectRecordEntity checkEffectRecordEntity = new CheckEffectRecordEntity();
        checkEffectRecordEntity.initAttrValue();
        BeanUtils.copyProperties(entity,checkEffectRecordEntity, BeanUtil.getNullPropertyNames(entity));
        checkEffectRecordEntity.setId(null);
        checkEffectRecordEntity.setRecordId(entity.getId());
        if(entity.getSubMethod()== SubMethodEnum.系统自动.getValue()){
            checkEffectRecordEntity.setCheckStatus(CheckStatusEnum.已处理.getValue());     //自动扣分相设置为已处理
        }else {
            checkEffectRecordEntity.setCheckStatus(CheckStatusEnum.未处理.getValue());      //非自动扣分相设置为未处理
        }
        checkEffectRecordEntity.setCheckTime(new Date());
        checkEffectRecordService.save(checkEffectRecordEntity,context);
    }

    @Override
    public void updateProcessStatus(Long id, Integer status) throws AppException {
        if(id==null){
            throw new AppException("效能绩效记录Id不能为空");
        }
        PerformEffectRecordEntity entity = this.get(id);
        if(entity==null){
            throw new AppException("无效的效能绩效记录Id");
        }
        if(status==null){
            status=1; //处理状态(1.未核查,2.已核查)
        }
        PerformEffectRecordEntity update = new PerformEffectRecordEntity();
        update.setId(id);
        update.setProcessStatus(status);
        update.setUpdateTime(new Date());
        dao.update(update);
    }

}