package com.mortals.xhx.module.perform.service.impl;
import com.mortals.xhx.common.code.CheckStatusEnum;
import com.mortals.xhx.common.code.SubMethodEnum;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.module.check.model.CheckOtherRecordEntity;
import com.mortals.xhx.module.check.service.CheckOtherRecordService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.perform.dao.PerformOtherRecordDao;
import com.mortals.xhx.module.perform.model.PerformOtherRecordEntity;
import com.mortals.xhx.module.perform.service.PerformOtherRecordService;
import lombok.extern.slf4j.Slf4j;

import java.util.Date;

/**
* PerformOtherRecordService
* 其它绩效记录信息 service实现
*
* @author zxfei
* @date 2023-07-11
*/
@Service("performOtherRecordService")
@Slf4j
public class PerformOtherRecordServiceImpl extends AbstractCRUDServiceImpl<PerformOtherRecordDao, PerformOtherRecordEntity, Long> implements PerformOtherRecordService {

    @Autowired
    private CheckOtherRecordService checkOtherRecordService;

    @Override
    protected void saveAfter(PerformOtherRecordEntity entity, Context context) throws AppException {
        CheckOtherRecordEntity checkOtherRecordEntity = new CheckOtherRecordEntity();
        checkOtherRecordEntity.initAttrValue();
        BeanUtils.copyProperties(entity,checkOtherRecordEntity, BeanUtil.getNullPropertyNames(entity));
        checkOtherRecordEntity.setId(null);
        checkOtherRecordEntity.setRecordId(entity.getId());
        if(entity.getSubMethod()== SubMethodEnum.系统自动.getValue()){
            checkOtherRecordEntity.setCheckStatus(CheckStatusEnum.已处理.getValue());     //自动扣分相设置为已处理
        }else {
            checkOtherRecordEntity.setCheckStatus(CheckStatusEnum.未处理.getValue());      //非自动扣分相设置为未处理
        }
        checkOtherRecordEntity.setCheckTime(new Date());
        checkOtherRecordService.save(checkOtherRecordEntity,context);
    }

    @Override
    public void updateProcessStatus(Long id, Integer status) throws AppException {
        if(id==null){
            throw new AppException("其它绩效记录Id不能为空");
        }
        PerformOtherRecordEntity entity = this.get(id);
        if(entity==null){
            throw new AppException("无效的其它绩效记录Id");
        }
        if(status==null){
            status=1; //处理状态(1.未核查,2.已核查)
        }
        PerformOtherRecordEntity update = new PerformOtherRecordEntity();
        update.setId(id);
        update.setProcessStatus(status);
        update.setUpdateTime(new Date());
        dao.update(update);
    }

}